#
# spec file for package vinagre
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without rdp
Name:           vinagre
Version:        3.22.0
Release:        lp150.4.5
Summary:        VNC client for GNOME
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Other
Url:            http://www.gnome.org/projects/vinagre/
Source0:        http://download.gnome.org/sources/vinagre/3.22/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM vinagre-freerdp2.patch bgo#765444 bgo#775616 mgorse@suse.com -- handle new "freerdp2" package name.
Patch1:         vinagre-freerdp2.patch
# PATCH-FIX-UPSTREAM vinagre-cert-validation-api.patch bgo#774473 boo#100235 fezhang@suse.com -- fix API incompatibilities with freerdp 1.2 that causes rdp connections abort
Patch2:         vinagre-cert-validation-api.patch
# The icon we rely on is from adwaita-icon-theme
# PATCH-FIX-UPSTREAM vinagre-invisible-fullscreen-toolbar.patch bgo#770484 boo#1008585 badshah400@opensuse.org -- Fix showing of toolbar as invisible in fullscreen mode; patch taken from upstream bug comment
Patch3:         vinagre-invisible-fullscreen-toolbar.patch
BuildRequires:  adwaita-icon-theme
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gdbm-devel
# Next two lines needed for Patch1
BuildRequires:  gnome-common
BuildRequires:  intltool >= 0.50.0
BuildRequires:  pkgconfig
# We need the %%mime_database_* macros
BuildRequires:  shared-mime-info
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(appstream-glib) >= 0.7.3
BuildRequires:  pkgconfig(avahi-gobject)
BuildRequires:  pkgconfig(avahi-ui-gtk3)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.9.6
BuildRequires:  pkgconfig(gtk-vnc-2.0) >= 0.4.3
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.31
BuildRequires:  pkgconfig(spice-client-gtk-3.0) >= 0.5
BuildRequires:  pkgconfig(telepathy-glib)
BuildRequires:  pkgconfig(vte-2.91)
BuildRequires:  pkgconfig(x11)
Recommends:     %{name}-lang
Obsoletes:      %{name}-devel < %{version}
%glib2_gsettings_schema_requires
%if %{with rdp}
BuildRequires:  pkgconfig(freerdp2)
%endif

%description
Vinagre is a VNC client for GNOME that supports connecting to multiple
machines, browsing for VNC servers via avahi and password storage in
gnome-keyring.

%lang_package

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
translation-update-upstream

%build
# Needed for Patch1
autoreconf
export CFLAGS="%{optflags} -Wno-error=format-nonliteral"
%configure --disable-static \
    --disable-scrollkeeper  \
%if %{with rdp}
    --enable-rdp            \
%endif
    --enable-spice          \
    --enable-ssh
make V=1 %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file -G "Remote Desktop Viewer" vinagre
%suse_update_desktop_file vinagre-file
%find_lang %{name} %{?no_lang_C}
for size in 8x8 16x16 22x22 24x24 32x32 48x48 256x256; do
        if test -f %{_datadir}/icons/gnome/$size/apps/preferences-desktop-remote-desktop.png; then
                mkdir -p %{buildroot}%{_datadir}/icons/hicolor/$size/apps
                cp -a %{_datadir}/icons/gnome/$size/apps/preferences-desktop-remote-desktop.png %{buildroot}%{_datadir}/icons/hicolor/$size/apps/preferences-desktop-remote-desktop.png
        fi
done

%fdupes %{buildroot}

%if 0%{?suse_version} < 1500
%post
%glib2_gsettings_schema_post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun
%endif

%files
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/vinagre
%{_datadir}/applications/vinagre.desktop
%{_datadir}/applications/vinagre-file.desktop
%{_datadir}/dbus-1/services/org.freedesktop.Telepathy.Client.Vinagre.service
%dir %{_datadir}/GConf
%dir %{_datadir}/GConf/gsettings
%{_datadir}/GConf/gsettings/org.gnome.Vinagre.convert
%{_datadir}/glib-2.0/schemas/org.gnome.Vinagre.gschema.xml
%{_datadir}/icons/hicolor/*/*/*
# Own dir for openSUSE Leap
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/vinagre.appdata.xml
%{_datadir}/mime/packages/vinagre-mime.xml
%{_datadir}/telepathy/clients/Vinagre.client
%dir %{_datadir}/vinagre
%{_datadir}/vinagre/vinagre*
%{_mandir}/man1/*.1%{ext_man}
# Own directories that are not owned by anything else
%dir %{_datadir}/telepathy
%dir %{_datadir}/telepathy/clients

%files lang -f %{name}.lang

%changelog
* Mon Mar 19 2018 badshah400@gmail.com
- Add vinagre-invisible-fullscreen-toolbar.patch: Fix showing of
  toolbar as invisible in fullscreen mode (bgo#770484,
  boo#1008585); patch taken from upstream bug comment.
- Only run post scripts for openSUSE < 1500; for newer versions
  these runs are taken care of rpm file triggers and no longer
  needed.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update License to GPL-3.0-or-later: various files are licensed
  this way, moving the entire project up.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Oct 25 2017 malcolmlewis@opensuse.org
- Change appstream file location due to appstream-glib >= 0.7.3.
* Fri Jun  2 2017 zaitor@opensuse.org
- Update vinagre-freerdp2.patch with patch from bgo#775616. Fix
  build with even later versions of freerdp.
* Tue May 16 2017 dimstar@opensuse.org
- Add -Wno-error=format-nonliteral to CFLAGS: fix build with gcc 7
  (boo#1031342).
* Tue Nov 15 2016 fezhang@suse.com
- Add vinagre-cert-validation-api.patch:
  Fix certificate validation callback incompatibilities with
  freerdp 1.2 that causes rdp connections to abort (bgo#774473,
  boo#1002350).
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + No changes.
* Wed Sep 14 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Improve FreeRDP authentication failure handling.
  + Correctly handle extended scancodes for RDP.
  + Updated translations.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Updated translations.
* Fri May 27 2016 mgorse@suse.com
- Enable rdp by default, since we now have the 2.0 branch in
  factory. Switch bcond_with rdp to bcond_without rdp.
- Add vinagre-freerdp2.patch: make configure check for freerdp2,
  rather than just freerdp (bgo#765444).
- Following the above patch: Replace pkgconfig(freerdp) for
  pkgconfig(freerdp2). Also add gnome-common BuildRequires and pass
  autreconf as the patch touches the buildsystem. Further add
  pkgconfig(appstream-glib) BuildRequires, new dependency after the
  port to freerdp2.
* Thu May 26 2016 federico@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue May 10 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Updated translations.
* Fri May  6 2016 idonmez@suse.com
- Sync with Factory for new libvte support bsc#978804
- Drop vinagre-bnc874407-add-advanced-options.patch, rdp support
  is disabled.
* Tue Apr 12 2016 dimstar@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Don't capture key events of other tabs.
  + Give focus to new RDP tab.
  + Allow different logins to the same host.
  + Show correct tooltip for RDP tab.
  + Updated translations.
* Wed Feb 17 2016 dimstar@opensuse.org
- Disable RDP support (using bcond_with, so it can easily be
  toggled). If not building with rdp support, do not:
  - pass --enable-rdp to configure
  - BuildRequire pkgconfig(freerdp)
- Drop vinagre-revert-freerdp-versionbump.patch and
  vinagre-revert-font-smoothing.patch: they are no longer
  sufficient. FreeRDP started 1.1 and 1.2 branches but refuses to
  create releases. GNOME makes use of features found in the 1.1
  branch.
* Wed Nov 25 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Store credentials for RDP (bgo#753355).
  + Handle domain when looking for credentials (bgo#753355).
  + Add minimize button to the fullscreen toolbar (bgo#753626).
  + Fix build against recent versions of FreeRDP.
  + Updated translations.
- Rebase vinagre-revert-freerdp-versionbump.patch and
  vinagre-revert-font-smoothing.patch.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Revert "Accept IPv6 addresses".
  + Updated translations.
* Tue Oct 13 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Enabled font smoothing by default in RDP plugin.
  + Accept IPv6 addresses.
  + Updated translations.
- Add vinagre-revert-font-smoothing.patch: Revert the font
  smoothing as this relies on a new version of freerdp we do not
  yet have in openSUSE.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Allow scaling of RDP sessions.
  + Updated translations.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Use cached session size for RDP.
  + Fix selection rectangle when user leaves window.
  + Updated translations.
* Tue May 26 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Trivial const-correctness fix.
  + Fix building against newer FreeRDP versions.
  + Updated translations.
- Add vinagre-revert-freerdp-versionbump.patch: Revert upstreams
  adoptation to newer versions of freerdp (bgo#749124).
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + BSD: fix a couple of implicit declarations.
  + Change SPICE passwords limited to 60 characters.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Update screenshot in help for 3.16.
  + Fix distcheck with Automake 1.15.
  + Bugs fixed: bgo#700353.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Fix RDP initialization with recent FreeRDP.
  + Updated translations.
* Wed Dec 17 2014 badshah400@gmail.com
- Update to version 3.15.2:
  + Remove bashism from configure.ac.
  + Add name and summary elements to AppData.
  + Detect RDP hosts via Avahi.
  + Updated translations.
* Mon Dec 15 2014 zaitor@opensuse.org
- Update to version 3.14.3:
  + Fix freeing of RDP events during dispose.
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Remove bashism from configure.ac.
  + Add name and summary elements to AppData.
  + Detect RDP hosts via Avahi.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Use APPSTREAM_XML instead of APPDATA_XML.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Request RDP certificate verification if needed.
  + Avoid yes-no buttons in certificate dialogs.
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Enable RDP support during distcheck.
  + Fix some language in tooltip strings.
  + Use FreeRDP API in RDP plugin.
  + Updated translations.
- Add pkgconfig(freerdp) and pkgconfig(x11) BuildRequires: new
  dependecies for RDP support.
- Pass --enable-rdp to configure to ensure we build the support.
- Drop freerdp Recommends: we now rely on the library/API.
- Remove language handling for obsolete openSUSE versions.
- Add adwaita-icon-theme BuildRequires: on an installed system,
  libgtk-3-0 requires it. On build though, it is exlucded to avoid
  a cycle.
* Sun Jul 20 2014 zaitor@opensuse.org
- Drop gnome-icon-theme Requires too, not needed nor wanted
  anymore.
* Mon Jul 14 2014 mgorse@suse.com
- Update vinagre-bnc874407-add-advanced-options.patch:
  When calling xfreerdp, add advanced options before the host/port
  (bnc#874407).
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Port to vte-2.91 API.
  + Drop gnome-icon-theme dependency.
  + Updated translations.
- Drop gnome-icon-theme BuildRequires: no longer required.
- Replace pkgconfig(vte-2.90) BuildRequires with
  pkgconfig(vte-2.91), following upstreams port.
* Fri Jul  4 2014 mgorse@suse.com
- Add vinagre-bnc874407-add-advanced-options.patch: allow custom
  options to be passed to xfreerdp (bnc#874407).
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Misc fixes.
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Add AppData (bgo#722893).
  + Add icon to help and add license.
  + Don't close connect dialog when showing help.
  + Updated translations.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Fix Spice plugin auto-clipboard property enum.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Implement get_dimensions() virtual function for VNC and RDP.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Fix a logic bug in utils.show_many_errors().
  + Add recognize_file() API to VinagreProtocol interface.
  + Fill the right ipv6 notation when using avahi dialog.
  + Make the BookmarksTree widget smaller.
  + Bugs fixed: bgo#704744, bgo#648008.
  + Updated translations.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + VinagreTab: don't crash on screenshot.
  + Use xfreerdp for RDP support.
  + Show correct title in error dialog.
  + Updated translations.
- Change rdesktop Recommends to freerdp, following upstreams choice
  to use xfreerdp for RDP support.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Allow to customize desktop size for RDP protocol.
  + Updated translations.
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Fix help link in reverse connections (bgo#700014).
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Updated translations.
* Mon Mar  4 2013 zaitor@opensuse.org
- Update to version 3.7.91:
  + Updated translations.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Fix value of save_in_keyring output parameter.
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Use GPollableInputStream when checking SSH errors.
  + Updated translations.
* Mon Jan  7 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Do not use NULL attributes with libsecret (bgo#685041).
  + Fix missing prototypes warnings.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Fix up handling of commandline options
  + Migrate from libgnome-keyring to libsecret
  + Updated translations.
- Drop vinagre-cmdline-parsing.patch: fixed upstream
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-1), following upstreams port to libsecret.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Tue Jul 24 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Depend on intltool 0.50 for GSettings translations
  + Updated translations.
* Mon Jul 23 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Updated translations.
* Mon Jul 23 2012 dimstar@opensuse.org
- Add vinagre-cmdline-parsing.patch: Fix up handling of commandline
  options (bnc#722709, bgo#662586)
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Use example.com in address examples (bgo#672238)
  + Updated translations.
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + Fixed help/Makefile.am.
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Remove hack to find localized help: this has been fixed in
  find-lang.sh.
* Mon Mar 19 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Minor bugfixes.
  + Updated translations.
* Tue Feb 28 2012 fcrozat@suse.com
- Enable spice support:
  - add pkgconfig(spice-client-gtk-3.0) BuildRequires
  - pass --enable-spice to configure instead of --disable-spice
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Make host text entry editable in connect dialog
  + Improved documentation.
  + Updated translations.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Set the window on the reverse VNC listener
  + Remove spurious n-rows and n-columns properties
  + Fix some pointer type mismatch warnings
  + Link plugins into the vinagre binary (bgo#653558)
  + Switch help to build with yelp-tools (bgo#657669)
  + Build fixes (including bgo#660531, bgo#665368)
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Change gnome-doc-utils-devel BuildRequires to yelp-tools,
  following upstream change.
- Drop vinagre-fix-missing-header.patch: fixed upstream.
- Remove the custom CFLAGS we had in %%build as bgo#653558 was
  fixed.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Change the group names from lowercase to CamelCase
  + Use a button-sized image on "Authentication" button
  + Use GtkGrid rather than deprecated GtkTable
  + Updated translations.
* Wed Oct 26 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + Integrate fixes from 3.2.1.
  + Hold the slave PTY open so that SSH does not fail
  + Fix a truncated string marked for translation
  + Updated translations.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Fix implicit declaration in vinagre-tube-handler.c
  + Do not use deprecated gtk_widget_modify_bg()
  + Add range to history-size GSettings key
  + Display correct application icon in about dialog
  + Add missing includes to fix build on OpenBSD
  + Updated translations.
* Fri Oct 14 2011 dimstar@opensuse.org
- Add -wl,--no-as-needed to CFLAGS during the build in order to
  work arund bgo#653558: the plugins are not correctly dynamically
  loaded but are linked into the main binary.
* Mon Oct  3 2011 vuntz@opensuse.org
- Add explicit shared-mime-info BuildRequires since we use the
  %%mime_database_* macros.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Remove tab close button minimum size hacks
  + Remove deprecated GTK+ API usage
  + Updated translations.
- Stop passing --disable-maintainer-mode to configure: this is not
  needed anymore since usage of deprecated API got removed.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Fix a few trivial compiler warnings
  + Updated translations.
- Pass --disable-maintainer-mode to configure as a workaround: this
  lets use deprecated GTK+ API for now. We should not keep this
  flag in the long term, though.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Use correct compiler warning flags variable
  + Fixed bad wording in connect help
  + Updated translations.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Do not set empty text on the credential entry
  + Use a string constant for the help module name
  + Add help button to connect dialog
  + Updated translations.
* Mon Aug 15 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Connect the bookmark menu item "activate" signal
  + Disable Ctrl-Alt-Del action in view-only mode
  + Port from Gtk[H|V]Box to GtkBox
  + Rework the first-run keyboard shortcut message
  + Update first-run help button target
  + Default to 8 bit color depth for Telepathy tubes
  + Improve the help
  + Bugs fixed: bgo#614774
  + Updated translations.
- Rebase vinagre-fix-missing-header.patch.
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Add GConf to GSettings convert file
  + Remove the unused dummy plugin source files
  + Move about dialog text to GtkBuilder XML
  + Updated translations.
* Thu Jul  7 2011 vuntz@opensuse.org
- Rebuild the vala sources before building the code:
  vinagre-fix-missing-header.patch introduces a new file that needs
  to be generated. When the proper fix will be upstream, the file
  will be in the tarball and we won't need this step anymore.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Allow the main notebook to expand.
  + Convert some code to Vala.
  + Avoid NULL dereference if a URI has no hostname.
  + Distribute the config VAPI file.
  + Code improvements and cleanups.
  + Build fixes.
  + Updated documentation.
  + Updated translations.
- Update vinagre-fix-missing-header.patch with patch suggested by
  upstream.
- Add vala BuildRequires, needed for the patch.
* Thu Jun 16 2011 vuntz@opensuse.org
- Update to version 3.1.2:
  + Add static extension support, and convert plugins to this.
  + Integrate reverse-vnc plugin directly.
  + Remove the bookmarks side panel.
  + Remove the im-status plugin.
  + Remove libpeas and gobject-introspection support.
  + Documentation improvements.
  + Code cleanups.
  + Build fixes.
  + Updated translations.
- Remove now unneeded pkgconfig(libpeas-gtk-1.0) BuildRequires.
- Remove unneeded pkgconfig(libpanelapplet-4.0) BuildRequires: the
  applet was removed in 3.1.1.
- Remove devel subpackage, as there is no support for external
  plugins anymore, and add Obsoletes for vinagre-devel to main
  package for smooth upgrades.
- Add vinagre-fix-missing-header.patch: fix the build by adding the
  missing header not generated by vala.
* Mon May 16 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Remove panel applet
  + Use ‘remote desktop’ rather than ‘machine’
  + Mark only the connect action as being important
  + Make it possible to focus the hostname GtkEntry
  + Correct some UI strings and stock icon usage
  + Capitalise Vinagre in command-line option help
  + Fix help button in reverse connection dialog
  + Replace old DocBook help with Mallard help
  + Code improvements.
  + bgo#597110: Add help page for reverse connections
  + bgo#599690: Many UI and string changes
  + bgo#640082: Add X geometry command-line option
- Move *.gir file to devel subpackage.
* Thu Apr 28 2011 vuntz@opensuse.org
- Remove explicit Requires for gtk2-devel and libxml2-devel in
  devel subpackage: they will automatically be added the
  pkgconfig() way.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Leave initial focus set to the primary toolbar
  + Check for gnome-icon-theme during configure
  + Fix reverse-vnc GtkBuilder file search path
  + Minor updates to the man page
  + bgo#647497: fix the SSH plugin build.
- Drop vinagre-ssh.patch: fixed upstream.
- Remove gnome-common from BuildRequires and call to
  gnome-autogen.sh: not needed anymore now that patch is gone.
* Wed Apr 27 2011 vuntz@opensuse.org
- Change Group of devel subpackage to Development/Libraries/GNOME
  (from Productivity/Networking/Remote Desktop) to fix a rpmlint
  warning.
* Mon Apr 11 2011 dimstar@opensuse.org
- Add vinagre-ssh.patch: Fix building of ssh plugin, bgo#647497.
- Add gnome-common BuildRequires and call gnome-autogen.sh in
  setup, and re-enable ssh plugin.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Bump VINAGRE_ABI_VERSION to 3.0
  + Updated translations
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + Add some style classes and junctions to make vinagre look
    better.
  + Updated translations
- Changes from version 2.91.92:
  + Remove broken gtk-vnc log handler, bgo#632711
  + Port applet to new libpanel-applet API.
  + Build fixes.
  + Updated translations.
- Changes from version 2.91.91:
  + Features
  - Make GSettings schema translatable
  + Fixes
  - Overhaul configure script
  - Make the build partially non-recursive
  - Fix the build with introspection enabled
  - Adapt to GtkObject removal in GTK+ 3
  - Replace gdk_draw_* with cairo* in panel applet
  - Avoid NULL pointer dereference in plugins if introspection is
    disabled
  - Partially fix introspection build
  + Updated translations.
- Changes from version 2.91.8:
  + Add a Spice plugin.
  + Fix reverse VNC plugin
  + Complete the GSettings migration
  + Various build fixes
- Changes from version 2.91.7:
  + Build with GTK+ 3
  + Use GtkApplication
  + Use libpeas for plugins
- Changes from version 2.31.5:
  + Build with GTK+ 3
  + Updated translations.
- Changes from version 2.31.4:
  + Added basic RDP support
  + Allows using of an alternative ssh port when doing tunnel
  + Build with GSEAL
  + Removed password length limit for SSH connections
  + Minor fixes
  + Updated translations.
- Disable ssh support until it is fixed upstream.
- Move to pkgconfig()-style BuildRequires and GNOME 3:
  + Old ones: gnome-panel-devel, gtk-vnc-devel, gtk2-devel,,
    libavahi-gobject-devel, libgnome-keyring-devel,
    telepathy-glib-devel, vte-devel.
  + New ones: avahi-gobject, avahi-ui-gtk3, gnome-keyring-1,
    gtk+-3.0, gtk-vnc-2.0, libpanelapplet-4.0, libxml-2.0,
    telepathy-glib, vte-2.90.
- Add pkgconfig(libpeas-gtk-1.0) BuildRequires.
- Add gnome-icon-theme Requires as we need icons from there at
  runtime.
- Disable spice support with --disable-spice configure flag, until
  we have spice packages in Factory.
- Remove --enable-avahi configure flag, as autodetection is used in
  configure.
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros.
- Add "Remote Desktop Viewer" generic name to vinagre.desktop.
- Add symlink for preferences-desktop-remote-desktop from
  gnome-icon-theme to allow package check to pass.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Thu Oct  7 2010 vuntz@opensuse.org
- Go back to 2.30.3, since the 2.31 release cycle is used with 3.0
  as target in April, for vinagre, and we want something that is
  stable.
- Changes between 2.30.2 and 2.30.3:
  + Updated translations.
* Thu Jul 22 2010 vuntz@opensuse.org
- Add rdesktop Recommends for the RDP support.
- Change group to Productivity/Networking/Other since
  Productivity/Networking/Remote Desktop doesn't exist.
* Mon Jul  5 2010 dimstar@opensuse.org
- Update to version 2.31.4:
  + Added basic RDP support
  + Allows using of an alternative ssh port when doing tunnel
  + Build with GSEAL
  + Removed password length limit for SSH connections
  + Minor fixes
  + Updated translations.
* Wed Jun 23 2010 dimstar@opensuse.org
- Update to version 2.30.2:
  + Removed password length limit for SSH connections
  + Allows using of an alternative ssh port when doing tunnel
  + Updated translations.
* Thu May  6 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + Fix a crash when using SSH tunneling due to a not exported
    symbol
  + Added various comments for translators
  + Bump telepathy minimum version to 0.9.0
  + Fix SSH username saving in bookmarks
  + Make sure we use system ifaddrs.h thus showing the correct IP
    address in the Reverse Connections dialog
  + Updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Updated translations.
* Mon Feb 22 2010 vuntz@opensuse.org
- Update to version 2.29.91:
  + Updated translations.
* Tue Feb  9 2010 captain.magnus@opensuse.org
- Update to version 2.29.90:
  + Features
  - Improved SSH tunneling.
  - Show a message in the first run explaining menu accelerators
    and keyboard shortcuts behavior in Vinagre
  - Store window size, position, panel state, etc in the
    XDG_CACHE_DIR instead of GConf
  - Enable the username field for SSH connections
  - Option to keep the aspect ratio when using scaling
  - Modernize autotools
  - SSH plugin uses the username provided from mdns (Avahi)
  + Fixes
  - Fix build on Solaris
  - Drop 1px line at toolbar in fullscreen mode
  - Minor fixes
  + Translation updates
- Add gcc-c++ to BuildRequires: configure script now requires it.
* Thu Jan 28 2010 vuntz@opensuse.org
- Remove en@shaw translation on openSUSE 11.2 and earlier.
* Mon Jan 25 2010 captain.magnus@opensuse.org
- Update to version 2.29.6:
  + Added basic support to SSH tunneling, to be polished in next
    release
  + Updated Telepathy support to the new API
  + Translation updates
* Wed Dec 23 2009 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel, following the module split upstream.
* Thu Nov 19 2009 dimstar@opensuse.org
- Update to version 2.29.1:
  + Added a listener mode (similar to vncviewer -listen)
  + Added ability to request an screen update
  + Added ability to change depth color
  + Added ability to use JPEG compression (lossy encoding)
  + Added an toolbar in bookmarks panel
  + Use AM_SILENT_RULES if available
  + Requires gtk-vnc 0.3.10
  + Fix warnings and crashes activating bookmarks
  + Keep the aspect ratio when using scaling mode
  + Updated translations.
* Mon Sep 21 2009 dimstar@opensuse.org
- Update to version 2.28.0.1:
  + Fix build
  + Fix warnings activating mDNS bookmarks
  + Updated translations.
- Add gtk2- and libxml2-devel to -devel Requires.
* Mon Sep  7 2009 dimstar@opensuse.org
- Update to version 2.27.92:
  + Removed duplicated names in the UI file, avoiding crashes
  + Show IP addresses of avahi-discovered machines instead of names
  + Handle GConf errors in preferences
  + Updated translations.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 2.27.91:
  + Updated Unix man page.
  + Improvements in Telepathy tubes.
  + Toolbar in full screen mode is now centralized.
  + Updated documentation (help).
  + Updated translations.
* Wed Aug 12 2009 vuntz@novell.com
- Update to version 2.27.90:
  + Features and Fixes
  - Use GtkBuilder instead of Glade.
  - Added a *very basic* SSH plugin. Enable it with --enable-ssh
    in configure.
  - Panel applet is now optional. Disable it with
  - -disable-applet.
  - Toolbar in fullscreen mode is now centralized.
  - Screenshot can be saved in various formats.
  - New fullscreen command-line option.
  - New scaled command-line option.
  - If the server is omitted in the command line, 'localhost' is
    assumed.
  - Clipboard operations work even with special chars.
  + Updated translations.
- Drop vinagre-linking-order.patch: fixed upstream.
- Drop vinagre-build-fix.patch: fixed upstream.
- Remove call to gnome-autogen.sh, and gnome-common BuildRequires.
- Remove libglade2-devel BuildRequires.
- Pass --enable-ssh to configure, and add vte-devel to
  BuildRequires.
- Remove workaround to move a file that was not in the right
  directory (vinagre-plugin.png).
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 2.27.5:
  + New plugin system. All protocols should be implemented as a
    plugin. Initially we have only VNC plugin.
  + Telepathy tubes support. This allows you to access a screen of
    an IM contact.
  + Lots of minor fixes.
  + Updated translations.
- Add gnome-keyring-devel, telepathy-glib-devel BuildRequires.
- Add vinagre-linking-order.patch and vinagre-build-fix.patch to
  fix build.
- Add devel package, for development files needed to create
  plugins.
* Mon Jul 20 2009 vuntz@novell.com
- Use libexecdir instead of libdir in the file list to fix build.
- Do not package omf files twice.
* Tue May 19 2009 vuntz@novell.com
- Update to version 2.26.2:
  + Updated translations.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + bgo#574134 – Don't allow items name duplicated on bookmarks.
  + Updated translations.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Updated translations.
- Remove AutoReqProv: it's default now.
* Mon Mar  2 2009 mboman@suse.de
- Update to version 2.25.92:
  + Improved the authentication dialog
  + Allow IPv6 address in command line as well in the connection
    dialog. The address must be enclosed by square braces, for
    instance: [::a:b:c:d]. This is the same syntax used by RealVNC
  + Translation updates
* Mon Feb 16 2009 mboman@suse.de
- Update to version 2.25.91:
  + Translation updates
- Remove %%if checks for <= 10.2 in BuildRequires
- Remove glib2-devel, gnome-common, gnome-keyring-devel,
  gnome-vfs2-devel, gnutls-devel, perl-XML-Parser from
  BuildRequires
* Tue Feb  3 2009 mboman@suse.de
- Update to version 2.25.90:
  + Fix the applet icon on transparent panels
  + Handle --enable-avahi option in configure.ac correctly
  + Translation updates
* Thu Jan 29 2009 lmedinas@gmail.com
- Update to version 2.25.5:
  + Translation updates
* Tue Jan  6 2009 mboman@suse.de
- Update to version 2.25.4:
  + bgo#558596: Added minimize button to toolbar in fullscreen mode
  + Depends on gtk-vnc 0.3.8. This makes scaling work even on composited
    screens
  + Translation updates
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.3:
  + bgo#509948: Added an 'original size' option in the view menu.
  + bgo#557740: Make avahi optional again. Pass '--disable-avahi' to
    configure.
  + bgo#559526: Allow username in the authentication schema.
  + bgo#536896: Drag and drop ability: Bookmark can be added by dragging
    and dropping an tab into it.
  + bgo#549649: Folders in bookmarks.
  + New manual page, by Emilio Pozuelo Monfort and Halton Huo.
  + Added an initial preferences dialog.
  + bgo#554995: Create the parent directory before copying the old bookmarks
    file to the new location.
  + bgo#555803: Hides menu mnemonics.
  + bgo#559525: Better parse a .vnc file.
  + bgo#550596: Sort bookmarks alphabetically.
  + bgo#562526: Make 'vinagre --help' fully localized.
  + Translation updates
- Reviewed work from lmedinas
* Sun Dec 14 2008 lmedinas@gmail.com
- Update to version 2.24.2:
  + Bump to fix a security issue
  + Update translations
- Remove vinagre-format-string.patch included upstream
* Fri Dec 12 2008 rodrigo@novell.com
- Add upstream fix for bnc#457895
* Tue Oct 21 2008 mboman@suse.de
- Update to version 2.24.1:
  + bgo#554995: Create the parent directory before copying the old
    bookmarks file to the new location
  + Translation updates
* Tue Sep 23 2008 mboman@suse.de
- Update to version 2.24.0:
  + Translation updates
* Tue Sep  9 2008 maw@suse.de
- Update to version 2.23.92:
  + Support downscaling
  + Updated translations.
* Tue Sep  2 2008 mboman@novell.com
- Update to version 2.23.91:
  + Minor bug fixes
  + Translation updates
* Mon Jun 23 2008 maw@suse.de
- Update to version 2.23.4:
  + The large version increase is due to vinagre synchronizing its
    version numbers with those of the GNOME project at large
  + Now we grab the keyboard automatically when the focus is on
    Vinagre
  + Add a gconf option to disable all menu shortcuts, useful if
    you want to get rid of having your key presses being
    intercepted by Vinagre
  + Add a panel applet
  + Bugs fixed: bgo#536330, bgo#522100, bgo#515816, bgo#536111,
    bgo#531969, bln#233918, bgo#490841, bgo#530712, bgo#501165,
    bgo#518351, bgo#519145, bgo#531593, bgo#530582, bgo#476942,
    bgo#512918, and bgo#509945
  + Updated translations.
* Fri Apr 11 2008 vuntz@suse.de
- Update to version 0.5.1:
  + Updated translations.
* Thu Mar 13 2008 vuntz@suse.de
- Update to version 0.5.0:
  + Updated translations.
* Wed Mar  5 2008 maw@suse.de
- Update to version 0.4.92:
  + Fix an inconsistency in menu sensitivity
  + Updated translations.
* Tue Feb 19 2008 maw@suse.de
- Update to version 0.4.91:
  + Register ourselves as handler for the vnc:// protocol
  + Allow port numbers < 1024 (bgo#513381)
  + Updated translations
- Include gconf schema in the package.
* Fri Feb  1 2008 maw@suse.de
- Update to version 0.4.90:
  + Improved documentation, incl. a man page
  + Use gio instead of gnome-vfs
  + Depend on gtk-vnc 0.3.2
  + Updated translations.
* Thu Jan 17 2008 jpr@suse.de
- Initial package checkin
